use utf8;
use strict;
use warnings FATAL => 'all';

package Xyzzy::Database::Config;

use Clarity -self;

field db_dsn => sub { die "No db_dsn configured\n" };
field db_user => undef;
field db_pass => undef;

*set_databasedsn = *db_dsn;
*set_databaseusername = *db_user;
*set_databasepassword = *db_pass;

*set_db_dsn = *db_dsn;
*set_db_user = *db_user;
*set_db_pass = *db_pass;

field db_options => {
	PrintError => 0,
	RaiseError => 1,
	AutoCommit => 0,
	ShowErrorStatement => 1,
	FetchHashKeyName => 'NAME_lc',
	pg_enable_utf8 => 1,
};
